"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _HostRequestStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _HostRequestStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_HostRequestStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    HOST_REQUEST_STATUS_PENDING: _HostRequestStatus.ValueType  # 0
    HOST_REQUEST_STATUS_ACCEPTED: _HostRequestStatus.ValueType  # 1
    HOST_REQUEST_STATUS_REJECTED: _HostRequestStatus.ValueType  # 2
    HOST_REQUEST_STATUS_CONFIRMED: _HostRequestStatus.ValueType  # 3
    HOST_REQUEST_STATUS_CANCELLED: _HostRequestStatus.ValueType  # 4

class HostRequestStatus(_HostRequestStatus, metaclass=_HostRequestStatusEnumTypeWrapper): ...

HOST_REQUEST_STATUS_PENDING: HostRequestStatus.ValueType  # 0
HOST_REQUEST_STATUS_ACCEPTED: HostRequestStatus.ValueType  # 1
HOST_REQUEST_STATUS_REJECTED: HostRequestStatus.ValueType  # 2
HOST_REQUEST_STATUS_CONFIRMED: HostRequestStatus.ValueType  # 3
HOST_REQUEST_STATUS_CANCELLED: HostRequestStatus.ValueType  # 4
Global___HostRequestStatus: typing_extensions.TypeAlias = HostRequestStatus

@typing.final
class MessageContentText(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    text: builtins.str
    """plain text"""
    def __init__(
        self,
        *,
        text: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["text", b"text"]) -> None: ...

Global___MessageContentText: typing_extensions.TypeAlias = MessageContentText

@typing.final
class MessageContentChatCreated(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___MessageContentChatCreated: typing_extensions.TypeAlias = MessageContentChatCreated

@typing.final
class MessageContentChatEdited(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___MessageContentChatEdited: typing_extensions.TypeAlias = MessageContentChatEdited

@typing.final
class MessageContentUserInvited(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_USER_ID_FIELD_NUMBER: builtins.int
    target_user_id: builtins.int
    def __init__(
        self,
        *,
        target_user_id: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["target_user_id", b"target_user_id"]) -> None: ...

Global___MessageContentUserInvited: typing_extensions.TypeAlias = MessageContentUserInvited

@typing.final
class MessageContentUserLeft(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___MessageContentUserLeft: typing_extensions.TypeAlias = MessageContentUserLeft

@typing.final
class MessageContentUserMadeAdmin(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_USER_ID_FIELD_NUMBER: builtins.int
    target_user_id: builtins.int
    def __init__(
        self,
        *,
        target_user_id: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["target_user_id", b"target_user_id"]) -> None: ...

Global___MessageContentUserMadeAdmin: typing_extensions.TypeAlias = MessageContentUserMadeAdmin

@typing.final
class MessageContentUserRemovedAdmin(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_USER_ID_FIELD_NUMBER: builtins.int
    target_user_id: builtins.int
    def __init__(
        self,
        *,
        target_user_id: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["target_user_id", b"target_user_id"]) -> None: ...

Global___MessageContentUserRemovedAdmin: typing_extensions.TypeAlias = MessageContentUserRemovedAdmin

@typing.final
class MessageContentUserRemoved(google.protobuf.message.Message):
    """field in Message, when a user is removed by admin"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_USER_ID_FIELD_NUMBER: builtins.int
    target_user_id: builtins.int
    def __init__(
        self,
        *,
        target_user_id: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["target_user_id", b"target_user_id"]) -> None: ...

Global___MessageContentUserRemoved: typing_extensions.TypeAlias = MessageContentUserRemoved

@typing.final
class MessageContentHostRequestStatusChanged(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    status: Global___HostRequestStatus.ValueType
    """this is the new host request status"""
    def __init__(
        self,
        *,
        status: Global___HostRequestStatus.ValueType | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["status", b"status"]) -> None: ...

Global___MessageContentHostRequestStatusChanged: typing_extensions.TypeAlias = MessageContentHostRequestStatusChanged

@typing.final
class Message(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_ID_FIELD_NUMBER: builtins.int
    AUTHOR_USER_ID_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    CHAT_CREATED_FIELD_NUMBER: builtins.int
    CHAT_EDITED_FIELD_NUMBER: builtins.int
    USER_INVITED_FIELD_NUMBER: builtins.int
    USER_LEFT_FIELD_NUMBER: builtins.int
    USER_MADE_ADMIN_FIELD_NUMBER: builtins.int
    USER_REMOVED_ADMIN_FIELD_NUMBER: builtins.int
    HOST_REQUEST_STATUS_CHANGED_FIELD_NUMBER: builtins.int
    GROUP_CHAT_USER_REMOVED_FIELD_NUMBER: builtins.int
    message_id: builtins.int
    author_user_id: builtins.int
    @property
    def time(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def text(self) -> Global___MessageContentText:
        """plain text"""

    @property
    def chat_created(self) -> Global___MessageContentChatCreated: ...
    @property
    def chat_edited(self) -> Global___MessageContentChatEdited: ...
    @property
    def user_invited(self) -> Global___MessageContentUserInvited: ...
    @property
    def user_left(self) -> Global___MessageContentUserLeft: ...
    @property
    def user_made_admin(self) -> Global___MessageContentUserMadeAdmin: ...
    @property
    def user_removed_admin(self) -> Global___MessageContentUserRemovedAdmin: ...
    @property
    def host_request_status_changed(self) -> Global___MessageContentHostRequestStatusChanged: ...
    @property
    def group_chat_user_removed(self) -> Global___MessageContentUserRemoved:
        """user removed by admin"""

    def __init__(
        self,
        *,
        message_id: builtins.int | None = ...,
        author_user_id: builtins.int | None = ...,
        time: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        text: Global___MessageContentText | None = ...,
        chat_created: Global___MessageContentChatCreated | None = ...,
        chat_edited: Global___MessageContentChatEdited | None = ...,
        user_invited: Global___MessageContentUserInvited | None = ...,
        user_left: Global___MessageContentUserLeft | None = ...,
        user_made_admin: Global___MessageContentUserMadeAdmin | None = ...,
        user_removed_admin: Global___MessageContentUserRemovedAdmin | None = ...,
        host_request_status_changed: Global___MessageContentHostRequestStatusChanged | None = ...,
        group_chat_user_removed: Global___MessageContentUserRemoved | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["chat_created", b"chat_created", "chat_edited", b"chat_edited", "content", b"content", "group_chat_user_removed", b"group_chat_user_removed", "host_request_status_changed", b"host_request_status_changed", "text", b"text", "time", b"time", "user_invited", b"user_invited", "user_left", b"user_left", "user_made_admin", b"user_made_admin", "user_removed_admin", b"user_removed_admin"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["author_user_id", b"author_user_id", "chat_created", b"chat_created", "chat_edited", b"chat_edited", "content", b"content", "group_chat_user_removed", b"group_chat_user_removed", "host_request_status_changed", b"host_request_status_changed", "message_id", b"message_id", "text", b"text", "time", b"time", "user_invited", b"user_invited", "user_left", b"user_left", "user_made_admin", b"user_made_admin", "user_removed_admin", b"user_removed_admin"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["content", b"content"]) -> typing.Literal["text", "chat_created", "chat_edited", "user_invited", "user_left", "user_made_admin", "user_removed_admin", "host_request_status_changed", "group_chat_user_removed"] | None: ...

Global___Message: typing_extensions.TypeAlias = Message

@typing.final
class MuteInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MUTED_FIELD_NUMBER: builtins.int
    MUTED_UNTIL_FIELD_NUMBER: builtins.int
    muted: builtins.bool
    @property
    def muted_until(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """muted_until is not present if muted forever"""

    def __init__(
        self,
        *,
        muted: builtins.bool | None = ...,
        muted_until: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["muted_until", b"muted_until"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["muted", b"muted", "muted_until", b"muted_until"]) -> None: ...

Global___MuteInfo: typing_extensions.TypeAlias = MuteInfo

@typing.final
class GroupChat(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_CHAT_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    MEMBER_USER_IDS_FIELD_NUMBER: builtins.int
    ADMIN_USER_IDS_FIELD_NUMBER: builtins.int
    ONLY_ADMINS_INVITE_FIELD_NUMBER: builtins.int
    IS_DM_FIELD_NUMBER: builtins.int
    CREATED_FIELD_NUMBER: builtins.int
    UNSEEN_MESSAGE_COUNT_FIELD_NUMBER: builtins.int
    LAST_SEEN_MESSAGE_ID_FIELD_NUMBER: builtins.int
    LATEST_MESSAGE_FIELD_NUMBER: builtins.int
    MUTE_INFO_FIELD_NUMBER: builtins.int
    CAN_MESSAGE_FIELD_NUMBER: builtins.int
    group_chat_id: builtins.int
    title: builtins.str
    only_admins_invite: builtins.bool
    is_dm: builtins.bool
    unseen_message_count: builtins.int
    last_seen_message_id: builtins.int
    can_message: builtins.bool
    @property
    def member_user_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]:
        """inclusive of admins"""

    @property
    def admin_user_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    @property
    def created(self) -> google.protobuf.timestamp_pb2.Timestamp: ...
    @property
    def latest_message(self) -> Global___Message: ...
    @property
    def mute_info(self) -> Global___MuteInfo: ...
    def __init__(
        self,
        *,
        group_chat_id: builtins.int | None = ...,
        title: builtins.str | None = ...,
        member_user_ids: collections.abc.Iterable[builtins.int] | None = ...,
        admin_user_ids: collections.abc.Iterable[builtins.int] | None = ...,
        only_admins_invite: builtins.bool | None = ...,
        is_dm: builtins.bool | None = ...,
        created: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        unseen_message_count: builtins.int | None = ...,
        last_seen_message_id: builtins.int | None = ...,
        latest_message: Global___Message | None = ...,
        mute_info: Global___MuteInfo | None = ...,
        can_message: builtins.bool | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created", b"created", "latest_message", b"latest_message", "mute_info", b"mute_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["admin_user_ids", b"admin_user_ids", "can_message", b"can_message", "created", b"created", "group_chat_id", b"group_chat_id", "is_dm", b"is_dm", "last_seen_message_id", b"last_seen_message_id", "latest_message", b"latest_message", "member_user_ids", b"member_user_ids", "mute_info", b"mute_info", "only_admins_invite", b"only_admins_invite", "title", b"title", "unseen_message_count", b"unseen_message_count"]) -> None: ...

Global___GroupChat: typing_extensions.TypeAlias = GroupChat

@typing.final
class GetGroupChatReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_CHAT_ID_FIELD_NUMBER: builtins.int
    group_chat_id: builtins.int
    def __init__(
        self,
        *,
        group_chat_id: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_chat_id", b"group_chat_id"]) -> None: ...

Global___GetGroupChatReq: typing_extensions.TypeAlias = GetGroupChatReq

@typing.final
class ListGroupChatsReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAST_MESSAGE_ID_FIELD_NUMBER: builtins.int
    NUMBER_FIELD_NUMBER: builtins.int
    last_message_id: builtins.int
    number: builtins.int
    def __init__(
        self,
        *,
        last_message_id: builtins.int | None = ...,
        number: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["last_message_id", b"last_message_id", "number", b"number"]) -> None: ...

Global___ListGroupChatsReq: typing_extensions.TypeAlias = ListGroupChatsReq

@typing.final
class ListGroupChatsRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_CHATS_FIELD_NUMBER: builtins.int
    LAST_MESSAGE_ID_FIELD_NUMBER: builtins.int
    NO_MORE_FIELD_NUMBER: builtins.int
    last_message_id: builtins.int
    no_more: builtins.bool
    @property
    def group_chats(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___GroupChat]: ...
    def __init__(
        self,
        *,
        group_chats: collections.abc.Iterable[Global___GroupChat] | None = ...,
        last_message_id: builtins.int | None = ...,
        no_more: builtins.bool | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_chats", b"group_chats", "last_message_id", b"last_message_id", "no_more", b"no_more"]) -> None: ...

Global___ListGroupChatsRes: typing_extensions.TypeAlias = ListGroupChatsRes

@typing.final
class GetUpdatesReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NEWEST_MESSAGE_ID_FIELD_NUMBER: builtins.int
    newest_message_id: builtins.int
    def __init__(
        self,
        *,
        newest_message_id: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["newest_message_id", b"newest_message_id"]) -> None: ...

Global___GetUpdatesReq: typing_extensions.TypeAlias = GetUpdatesReq

@typing.final
class GetDirectMessageReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.int
    def __init__(
        self,
        *,
        user_id: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["user_id", b"user_id"]) -> None: ...

Global___GetDirectMessageReq: typing_extensions.TypeAlias = GetDirectMessageReq

@typing.final
class Update(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_CHAT_ID_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    group_chat_id: builtins.int
    @property
    def message(self) -> Global___Message: ...
    def __init__(
        self,
        *,
        group_chat_id: builtins.int | None = ...,
        message: Global___Message | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["message", b"message"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["group_chat_id", b"group_chat_id", "message", b"message"]) -> None: ...

Global___Update: typing_extensions.TypeAlias = Update

@typing.final
class GetUpdatesRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPDATES_FIELD_NUMBER: builtins.int
    NO_MORE_FIELD_NUMBER: builtins.int
    no_more: builtins.bool
    @property
    def updates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Update]: ...
    def __init__(
        self,
        *,
        updates: collections.abc.Iterable[Global___Update] | None = ...,
        no_more: builtins.bool | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["no_more", b"no_more", "updates", b"updates"]) -> None: ...

Global___GetUpdatesRes: typing_extensions.TypeAlias = GetUpdatesRes

@typing.final
class GetGroupChatMessagesReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_CHAT_ID_FIELD_NUMBER: builtins.int
    LAST_MESSAGE_ID_FIELD_NUMBER: builtins.int
    NUMBER_FIELD_NUMBER: builtins.int
    ONLY_UNSEEN_FIELD_NUMBER: builtins.int
    group_chat_id: builtins.int
    last_message_id: builtins.int
    number: builtins.int
    only_unseen: builtins.bool
    def __init__(
        self,
        *,
        group_chat_id: builtins.int | None = ...,
        last_message_id: builtins.int | None = ...,
        number: builtins.int | None = ...,
        only_unseen: builtins.bool | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_chat_id", b"group_chat_id", "last_message_id", b"last_message_id", "number", b"number", "only_unseen", b"only_unseen"]) -> None: ...

Global___GetGroupChatMessagesReq: typing_extensions.TypeAlias = GetGroupChatMessagesReq

@typing.final
class GetGroupChatMessagesRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGES_FIELD_NUMBER: builtins.int
    LAST_MESSAGE_ID_FIELD_NUMBER: builtins.int
    NO_MORE_FIELD_NUMBER: builtins.int
    last_message_id: builtins.int
    no_more: builtins.bool
    @property
    def messages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Message]: ...
    def __init__(
        self,
        *,
        messages: collections.abc.Iterable[Global___Message] | None = ...,
        last_message_id: builtins.int | None = ...,
        no_more: builtins.bool | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["last_message_id", b"last_message_id", "messages", b"messages", "no_more", b"no_more"]) -> None: ...

Global___GetGroupChatMessagesRes: typing_extensions.TypeAlias = GetGroupChatMessagesRes

@typing.final
class MarkLastSeenGroupChatReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_CHAT_ID_FIELD_NUMBER: builtins.int
    LAST_SEEN_MESSAGE_ID_FIELD_NUMBER: builtins.int
    group_chat_id: builtins.int
    last_seen_message_id: builtins.int
    def __init__(
        self,
        *,
        group_chat_id: builtins.int | None = ...,
        last_seen_message_id: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_chat_id", b"group_chat_id", "last_seen_message_id", b"last_seen_message_id"]) -> None: ...

Global___MarkLastSeenGroupChatReq: typing_extensions.TypeAlias = MarkLastSeenGroupChatReq

@typing.final
class MuteGroupChatReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_CHAT_ID_FIELD_NUMBER: builtins.int
    UNMUTE_FIELD_NUMBER: builtins.int
    FOREVER_FIELD_NUMBER: builtins.int
    FOR_DURATION_FIELD_NUMBER: builtins.int
    group_chat_id: builtins.int
    unmute: builtins.bool
    forever: builtins.bool
    @property
    def for_duration(self) -> google.protobuf.duration_pb2.Duration: ...
    def __init__(
        self,
        *,
        group_chat_id: builtins.int | None = ...,
        unmute: builtins.bool | None = ...,
        forever: builtins.bool | None = ...,
        for_duration: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["duration", b"duration", "for_duration", b"for_duration", "forever", b"forever", "unmute", b"unmute"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["duration", b"duration", "for_duration", b"for_duration", "forever", b"forever", "group_chat_id", b"group_chat_id", "unmute", b"unmute"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["duration", b"duration"]) -> typing.Literal["unmute", "forever", "for_duration"] | None: ...

Global___MuteGroupChatReq: typing_extensions.TypeAlias = MuteGroupChatReq

@typing.final
class CreateGroupChatReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    RECIPIENT_USER_IDS_FIELD_NUMBER: builtins.int
    @property
    def title(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def recipient_user_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    def __init__(
        self,
        *,
        title: google.protobuf.wrappers_pb2.StringValue | None = ...,
        recipient_user_ids: collections.abc.Iterable[builtins.int] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["title", b"title"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["recipient_user_ids", b"recipient_user_ids", "title", b"title"]) -> None: ...

Global___CreateGroupChatReq: typing_extensions.TypeAlias = CreateGroupChatReq

@typing.final
class EditGroupChatReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_CHAT_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    ONLY_ADMINS_INVITE_FIELD_NUMBER: builtins.int
    group_chat_id: builtins.int
    @property
    def title(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def only_admins_invite(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    def __init__(
        self,
        *,
        group_chat_id: builtins.int | None = ...,
        title: google.protobuf.wrappers_pb2.StringValue | None = ...,
        only_admins_invite: google.protobuf.wrappers_pb2.BoolValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["only_admins_invite", b"only_admins_invite", "title", b"title"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["group_chat_id", b"group_chat_id", "only_admins_invite", b"only_admins_invite", "title", b"title"]) -> None: ...

Global___EditGroupChatReq: typing_extensions.TypeAlias = EditGroupChatReq

@typing.final
class InviteToGroupChatReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_CHAT_ID_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    group_chat_id: builtins.int
    user_id: builtins.int
    def __init__(
        self,
        *,
        group_chat_id: builtins.int | None = ...,
        user_id: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_chat_id", b"group_chat_id", "user_id", b"user_id"]) -> None: ...

Global___InviteToGroupChatReq: typing_extensions.TypeAlias = InviteToGroupChatReq

@typing.final
class MakeGroupChatAdminReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_CHAT_ID_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    group_chat_id: builtins.int
    user_id: builtins.int
    def __init__(
        self,
        *,
        group_chat_id: builtins.int | None = ...,
        user_id: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_chat_id", b"group_chat_id", "user_id", b"user_id"]) -> None: ...

Global___MakeGroupChatAdminReq: typing_extensions.TypeAlias = MakeGroupChatAdminReq

@typing.final
class RemoveGroupChatUserReq(google.protobuf.message.Message):
    """required fields and types"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_CHAT_ID_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    group_chat_id: builtins.int
    user_id: builtins.int
    def __init__(
        self,
        *,
        group_chat_id: builtins.int | None = ...,
        user_id: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_chat_id", b"group_chat_id", "user_id", b"user_id"]) -> None: ...

Global___RemoveGroupChatUserReq: typing_extensions.TypeAlias = RemoveGroupChatUserReq

@typing.final
class RemoveGroupChatAdminReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_CHAT_ID_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    group_chat_id: builtins.int
    user_id: builtins.int
    def __init__(
        self,
        *,
        group_chat_id: builtins.int | None = ...,
        user_id: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_chat_id", b"group_chat_id", "user_id", b"user_id"]) -> None: ...

Global___RemoveGroupChatAdminReq: typing_extensions.TypeAlias = RemoveGroupChatAdminReq

@typing.final
class SendMessageReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_CHAT_ID_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    group_chat_id: builtins.int
    text: builtins.str
    def __init__(
        self,
        *,
        group_chat_id: builtins.int | None = ...,
        text: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_chat_id", b"group_chat_id", "text", b"text"]) -> None: ...

Global___SendMessageReq: typing_extensions.TypeAlias = SendMessageReq

@typing.final
class SendDirectMessageReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RECIPIENT_USER_ID_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    recipient_user_id: builtins.int
    text: builtins.str
    def __init__(
        self,
        *,
        recipient_user_id: builtins.int | None = ...,
        text: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["recipient_user_id", b"recipient_user_id", "text", b"text"]) -> None: ...

Global___SendDirectMessageReq: typing_extensions.TypeAlias = SendDirectMessageReq

@typing.final
class SendDirectMessageRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_CHAT_ID_FIELD_NUMBER: builtins.int
    group_chat_id: builtins.int
    def __init__(
        self,
        *,
        group_chat_id: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_chat_id", b"group_chat_id"]) -> None: ...

Global___SendDirectMessageRes: typing_extensions.TypeAlias = SendDirectMessageRes

@typing.final
class LeaveGroupChatReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_CHAT_ID_FIELD_NUMBER: builtins.int
    group_chat_id: builtins.int
    def __init__(
        self,
        *,
        group_chat_id: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_chat_id", b"group_chat_id"]) -> None: ...

Global___LeaveGroupChatReq: typing_extensions.TypeAlias = LeaveGroupChatReq

@typing.final
class SearchMessagesReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUERY_FIELD_NUMBER: builtins.int
    LAST_MESSAGE_ID_FIELD_NUMBER: builtins.int
    NUMBER_FIELD_NUMBER: builtins.int
    query: builtins.str
    last_message_id: builtins.int
    number: builtins.int
    def __init__(
        self,
        *,
        query: builtins.str | None = ...,
        last_message_id: builtins.int | None = ...,
        number: builtins.int | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["last_message_id", b"last_message_id", "number", b"number", "query", b"query"]) -> None: ...

Global___SearchMessagesReq: typing_extensions.TypeAlias = SearchMessagesReq

@typing.final
class MessageSearchResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GROUP_CHAT_ID_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    group_chat_id: builtins.int
    @property
    def message(self) -> Global___Message: ...
    def __init__(
        self,
        *,
        group_chat_id: builtins.int | None = ...,
        message: Global___Message | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["message", b"message"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["group_chat_id", b"group_chat_id", "message", b"message"]) -> None: ...

Global___MessageSearchResult: typing_extensions.TypeAlias = MessageSearchResult

@typing.final
class SearchMessagesRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULTS_FIELD_NUMBER: builtins.int
    LAST_MESSAGE_ID_FIELD_NUMBER: builtins.int
    NO_MORE_FIELD_NUMBER: builtins.int
    last_message_id: builtins.int
    no_more: builtins.bool
    @property
    def results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___MessageSearchResult]: ...
    def __init__(
        self,
        *,
        results: collections.abc.Iterable[Global___MessageSearchResult] | None = ...,
        last_message_id: builtins.int | None = ...,
        no_more: builtins.bool | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["last_message_id", b"last_message_id", "no_more", b"no_more", "results", b"results"]) -> None: ...

Global___SearchMessagesRes: typing_extensions.TypeAlias = SearchMessagesRes



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: search.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import annotations_pb2 as annotations__pb2
from . import api_pb2 as api__pb2
from . import communities_pb2 as communities__pb2
from . import events_pb2 as events__pb2
from . import groups_pb2 as groups__pb2
from . import pages_pb2 as pages__pb2
from . import requests_pb2 as requests__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0csearch.proto\x12\x17org.couchers.api.search\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x61nnotations.proto\x1a\tapi.proto\x1a\x11\x63ommunities.proto\x1a\x0c\x65vents.proto\x1a\x0cgroups.proto\x1a\x0bpages.proto\x1a\x0erequests.proto\"0\n\x04\x41rea\x12\x0b\n\x03lat\x18\x01 \x01(\x01\x12\x0b\n\x03lng\x18\x02 \x01(\x01\x12\x0e\n\x06radius\x18\x03 \x01(\x01\"N\n\x08RectArea\x12\x0f\n\x07lat_min\x18\x01 \x01(\x01\x12\x0f\n\x07lat_max\x18\x02 \x01(\x01\x12\x0f\n\x07lng_min\x18\x03 \x01(\x01\x12\x0f\n\x07lng_max\x18\x04 \x01(\x01\"\xe9\x01\n\tSearchReq\x12\r\n\x05query\x18\x01 \x01(\t\x12\x15\n\rinclude_users\x18\x04 \x01(\x08\x12\x1b\n\x13include_communities\x18\x05 \x01(\x08\x12\x16\n\x0einclude_groups\x18\x06 \x01(\x08\x12\x16\n\x0einclude_places\x18\x07 \x01(\x08\x12\x16\n\x0einclude_guides\x18\x08 \x01(\x08\x12\x16\n\x0einclude_events\x18\n \x01(\x08\x12\x12\n\ntitle_only\x18\r \x01(\x08\x12\x11\n\tpage_size\x18\x02 \x01(\r\x12\x12\n\npage_token\x18\x03 \x01(\t\"\xdc\x02\n\x06Result\x12\x0c\n\x04rank\x18\x01 \x01(\x01\x12\x0f\n\x07snippet\x18\x02 \x01(\t\x12+\n\x04user\x18\x03 \x01(\x0b\x32\x1b.org.couchers.api.core.UserH\x00\x12<\n\tcommunity\x18\x04 \x01(\x0b\x32\'.org.couchers.api.communities.CommunityH\x00\x12/\n\x05group\x18\x05 \x01(\x0b\x32\x1e.org.couchers.api.groups.GroupH\x00\x12-\n\x05place\x18\x06 \x01(\x0b\x32\x1c.org.couchers.api.pages.PageH\x00\x12-\n\x05guide\x18\x07 \x01(\x0b\x32\x1c.org.couchers.api.pages.PageH\x00\x12/\n\x05\x65vent\x18\x08 \x01(\x0b\x32\x1e.org.couchers.api.events.EventH\x00\x42\x08\n\x06result\"V\n\tSearchRes\x12\x30\n\x07results\x18\x01 \x03(\x0b\x32\x1f.org.couchers.api.search.Result\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xa0\r\n\rUserSearchReq\x12\x18\n\x10\x65xactly_user_ids\x18# \x03(\x03\x12+\n\x05query\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x17\n\x0fquery_name_only\x18\x1e \x01(\x08\x12/\n\x0blast_active\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\x0esearch_in_area\x18\x1c \x01(\x0b\x32\x1d.org.couchers.api.search.AreaH\x00\x12 \n\x16search_in_community_id\x18\x1d \x01(\x03H\x00\x12@\n\x13search_in_rectangle\x18! \x01(\x0b\x32!.org.couchers.api.search.RectAreaH\x00\x12\x43\n\x15hosting_status_filter\x18\x05 \x03(\x0e\x32$.org.couchers.api.core.HostingStatus\x12G\n\x17smoking_location_filter\x18\x06 \x03(\x0e\x32&.org.couchers.api.core.SmokingLocation\x12O\n\x1bsleeping_arrangement_filter\x18\x07 \x03(\x0e\x32*.org.couchers.api.core.SleepingArrangement\x12\x45\n\x16parking_details_filter\x18\x08 \x03(\x0e\x32%.org.couchers.api.core.ParkingDetails\x12\x41\n\x14meetup_status_filter\x18  \x03(\x0e\x32#.org.couchers.api.core.MeetupStatus\x12G\n\x17language_ability_filter\x18\x0b \x03(\x0b\x32&.org.couchers.api.core.LanguageAbility\x12,\n\x06guests\x18\n \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x1c\n\x14only_with_references\x18\x0c \x01(\x08\x12%\n\x1donly_with_strong_verification\x18\" \x01(\x08\x12-\n\x07\x61ge_min\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12-\n\x07\x61ge_max\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12/\n\x0blast_minute\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12,\n\x08has_pets\x18\x11 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x30\n\x0c\x61\x63\x63\x65pts_pets\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12,\n\x08has_kids\x18\x13 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x30\n\x0c\x61\x63\x63\x65pts_kids\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0ehas_housemates\x18\x15 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x39\n\x15wheelchair_accessible\x18\x16 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0esmokes_at_home\x18\x17 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x34\n\x10\x64rinking_allowed\x18\x18 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0e\x64rinks_at_home\x18\x19 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12+\n\x07parking\x18\x1a \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12.\n\ncamping_ok\x18\x1b \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x35\n\x11profile_completed\x18\x1f \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x18\n\x10same_gender_only\x18$ \x01(\x08\x12\x11\n\tpage_size\x18\x01 \x01(\r\x12\x12\n\npage_token\x18\x02 \x01(\tB\x0b\n\tsearch_in\"o\n\rUserSearchRes\x12\x30\n\x07results\x18\x01 \x03(\x0b\x32\x1f.org.couchers.api.search.Result\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x13\n\x0btotal_items\x18\x03 \x01(\r\"\xff\x06\n\nSearchUser\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04\x63ity\x18\x04 \x01(\t\x12*\n\x06joined\x18\x18 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1d\n\x15has_completed_profile\x18\x05 \x01(\x08\x12\x1d\n\x15has_completed_my_home\x18\x17 \x01(\x08\x12\x0b\n\x03lat\x18\x06 \x01(\x01\x12\x0b\n\x03lng\x18\x07 \x01(\x01\x12\x17\n\x0fprofile_snippet\x18\x08 \x01(\t\x12\x16\n\x0enum_references\x18\t \x01(\r\x12\x0e\n\x06gender\x18\n \x01(\t\x12\x0b\n\x03\x61ge\x18\x0b \x01(\r\x12/\n\x0blast_active\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12<\n\x0ehosting_status\x18\r \x01(\x0e\x32$.org.couchers.api.core.HostingStatus\x12:\n\rmeetup_status\x18\x0e \x01(\x0e\x32#.org.couchers.api.core.MeetupStatus\x12\x12\n\navatar_url\x18\x0f \x01(\t\x12\x1c\n\x14\x61vatar_thumbnail_url\x18\x10 \x01(\t\x12\x1f\n\x17has_strong_verification\x18\x11 \x01(\x08\x12T\n\x11insufficient_data\x18\x12 \x01(\x0b\x32\x37.org.couchers.api.requests.ResponseRateInsufficientDataH\x00\x12\x39\n\x03low\x18\x13 \x01(\x0b\x32*.org.couchers.api.requests.ResponseRateLowH\x00\x12;\n\x04some\x18\x14 \x01(\x0b\x32+.org.couchers.api.requests.ResponseRateSomeH\x00\x12;\n\x04most\x18\x15 \x01(\x0b\x32+.org.couchers.api.requests.ResponseRateMostH\x00\x12\x46\n\nalmost_all\x18\x16 \x01(\x0b\x32\x30.org.couchers.api.requests.ResponseRateAlmostAllH\x00\x42\x0f\n\rresponse_rate\"u\n\x0fUserSearchV2Res\x12\x34\n\x07results\x18\x01 \x03(\x0b\x32#.org.couchers.api.search.SearchUser\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x13\n\x0btotal_items\x18\x03 \x01(\r\"\xe2\x04\n\x0e\x45ventSearchReq\x12\x0c\n\x04past\x18\x01 \x01(\x08\x12+\n\x05query\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x18\n\x10query_title_only\x18\x03 \x01(\x08\x12\x15\n\x0bonly_online\x18\x0c \x01(\x08H\x00\x12\x16\n\x0conly_offline\x18\r \x01(\x08H\x00\x12\x12\n\nsubscribed\x18\x0e \x01(\x08\x12\x11\n\tattending\x18\x0f \x01(\x08\x12\x12\n\norganizing\x18\x10 \x01(\x08\x12\x16\n\x0emy_communities\x18\x11 \x01(\x08\x12\x19\n\x11include_cancelled\x18\x04 \x01(\x08\x12\x37\n\x0esearch_in_area\x18\x05 \x01(\x0b\x32\x1d.org.couchers.api.search.AreaH\x01\x12 \n\x16search_in_community_id\x18\x06 \x01(\x03H\x01\x12@\n\x13search_in_rectangle\x18\x07 \x01(\x0b\x32!.org.couchers.api.search.RectAreaH\x01\x12)\n\x05\x61\x66ter\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x06\x62\x65\x66ore\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x11\n\tpage_size\x18\n \x01(\r\x12\x14\n\npage_token\x18\x0b \x01(\tH\x02\x12\x15\n\x0bpage_number\x18\x12 \x01(\rH\x02\x42\x0f\n\ronline_statusB\x0b\n\tsearch_inB\x0c\n\npagination\"n\n\x0e\x45ventSearchRes\x12.\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x1e.org.couchers.api.events.Event\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12\x13\n\x0btotal_items\x18\x04 \x01(\r2\x89\x03\n\x06Search\x12R\n\x06Search\x12\".org.couchers.api.search.SearchReq\x1a\".org.couchers.api.search.SearchRes\"\x00\x12^\n\nUserSearch\x12&.org.couchers.api.search.UserSearchReq\x1a&.org.couchers.api.search.UserSearchRes\"\x00\x12\x62\n\x0cUserSearchV2\x12&.org.couchers.api.search.UserSearchReq\x1a(.org.couchers.api.search.UserSearchV2Res\"\x00\x12\x61\n\x0b\x45ventSearch\x12\'.org.couchers.api.search.EventSearchReq\x1a\'.org.couchers.api.search.EventSearchRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'search_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SEARCH']._loaded_options = None
  _globals['_SEARCH']._serialized_options = b'\210\265\030\003'
  _globals['_AREA']._serialized_start=212
  _globals['_AREA']._serialized_end=260
  _globals['_RECTAREA']._serialized_start=262
  _globals['_RECTAREA']._serialized_end=340
  _globals['_SEARCHREQ']._serialized_start=343
  _globals['_SEARCHREQ']._serialized_end=576
  _globals['_RESULT']._serialized_start=579
  _globals['_RESULT']._serialized_end=927
  _globals['_SEARCHRES']._serialized_start=929
  _globals['_SEARCHRES']._serialized_end=1015
  _globals['_USERSEARCHREQ']._serialized_start=1018
  _globals['_USERSEARCHREQ']._serialized_end=2714
  _globals['_USERSEARCHRES']._serialized_start=2716
  _globals['_USERSEARCHRES']._serialized_end=2827
  _globals['_SEARCHUSER']._serialized_start=2830
  _globals['_SEARCHUSER']._serialized_end=3725
  _globals['_USERSEARCHV2RES']._serialized_start=3727
  _globals['_USERSEARCHV2RES']._serialized_end=3844
  _globals['_EVENTSEARCHREQ']._serialized_start=3847
  _globals['_EVENTSEARCHREQ']._serialized_end=4457
  _globals['_EVENTSEARCHRES']._serialized_start=4459
  _globals['_EVENTSEARCHRES']._serialized_end=4569
  _globals['_SEARCH']._serialized_start=4572
  _globals['_SEARCH']._serialized_end=4965
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: reporting.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0freporting.proto\x12\x1aorg.couchers.api.reporting\x1a\x1bgoogle/protobuf/empty.proto\x1a\x11\x61nnotations.proto\"|\n\tReportReq\x12\x0e\n\x06reason\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x13\n\x0b\x63ontent_ref\x18\x03 \x01(\t\x12\x13\n\x0b\x61uthor_user\x18\x04 \x01(\t\x12\x12\n\nuser_agent\x18\x05 \x01(\t\x12\x0c\n\x04page\x18\x06 \x01(\t2\\\n\tReporting\x12I\n\x06Report\x12%.org.couchers.api.reporting.ReportReq\x1a\x16.google.protobuf.Empty\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'reporting_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_REPORTING']._loaded_options = None
  _globals['_REPORTING']._serialized_options = b'\210\265\030\003'
  _globals['_REPORTREQ']._serialized_start=95
  _globals['_REPORTREQ']._serialized_end=219
  _globals['_REPORTING']._serialized_start=221
  _globals['_REPORTING']._serialized_end=313
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: editor.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import annotations_pb2 as annotations__pb2
from . import communities_pb2 as communities__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x65\x64itor.proto\x12\x13org.couchers.editor\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x11\x61nnotations.proto\x1a\x11\x63ommunities.proto\"s\n\x12\x43reateCommunityReq\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x16\n\x0eparent_node_id\x18\x04 \x01(\x03\x12\x11\n\tadmin_ids\x18\x05 \x03(\x03\x12\x0f\n\x07geojson\x18\x06 \x01(\t\"v\n\x12UpdateCommunityReq\x12\x14\n\x0c\x63ommunity_id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x16\n\x0eparent_node_id\x18\x04 \x01(\x03\x12\x0f\n\x07geojson\x18\x05 \x01(\t\"L\n#ListEventCommunityInviteRequestsReq\x12\x11\n\tpage_size\x18\x01 \x01(\r\x12\x12\n\npage_token\x18\x02 \x01(\t\"\xa2\x01\n\x1b\x45ventCommunityInviteRequest\x12)\n!event_community_invite_request_id\x18\x01 \x01(\x03\x12\x0f\n\x07user_id\x18\x02 \x01(\x03\x12\x11\n\tevent_url\x18\x03 \x01(\t\x12\x1e\n\x16\x61pprox_users_to_notify\x18\x04 \x01(\r\x12\x14\n\x0c\x63ommunity_id\x18\x05 \x01(\x03\"\x82\x01\n#ListEventCommunityInviteRequestsRes\x12\x42\n\x08requests\x18\x01 \x03(\x0b\x32\x30.org.couchers.editor.EventCommunityInviteRequest\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"b\n$DecideEventCommunityInviteRequestReq\x12)\n!event_community_invite_request_id\x18\x01 \x01(\x03\x12\x0f\n\x07\x61pprove\x18\x02 \x01(\x08\"&\n$DecideEventCommunityInviteRequestRes\"H\n\x1bSendBlogPostNotificationReq\x12\x0b\n\x03url\x18\x01 \x01(\t\x12\r\n\x05title\x18\x02 \x01(\t\x12\r\n\x05\x62lurb\x18\x03 \x01(\t\"n\n\x14MakeUserVolunteerReq\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x0c\n\x04role\x18\x02 \x01(\t\x12\x1c\n\x14started_volunteering\x18\x03 \x01(\t\x12\x19\n\x11hide_on_team_page\x18\x04 \x01(\x08\"\xb0\x02\n\x12UpdateVolunteerReq\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12*\n\x04role\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08sort_key\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12:\n\x14started_volunteering\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12:\n\x14stopped_volunteering\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x35\n\x11show_on_team_page\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\")\n\x11ListVolunteersReq\x12\x14\n\x0cinclude_past\x18\x01 \x01(\x08\"\x8b\x03\n\tVolunteer\x12\x0f\n\x07user_id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08username\x18\x03 \x01(\t\x12\x17\n\x0fis_board_member\x18\x04 \x01(\x08\x12\x0c\n\x04role\x18\x05 \x01(\t\x12\x10\n\x08location\x18\x06 \x01(\t\x12\x0b\n\x03img\x18\x07 \x01(\t\x12\x15\n\x08sort_key\x18\x08 \x01(\x01H\x00\x88\x01\x01\x12\x1c\n\x14started_volunteering\x18\t \x01(\t\x12!\n\x14stopped_volunteering\x18\n \x01(\tH\x01\x88\x01\x01\x12\x19\n\x11show_on_team_page\x18\x0b \x01(\x08\x12\x16\n\tlink_type\x18\x0c \x01(\tH\x02\x88\x01\x01\x12\x16\n\tlink_text\x18\r \x01(\tH\x03\x88\x01\x01\x12\x15\n\x08link_url\x18\x0e \x01(\tH\x04\x88\x01\x01\x42\x0b\n\t_sort_keyB\x17\n\x15_stopped_volunteeringB\x0c\n\n_link_typeB\x0c\n\n_link_textB\x0b\n\t_link_url\"G\n\x11ListVolunteersRes\x12\x32\n\nvolunteers\x18\x01 \x03(\x0b\x32\x1e.org.couchers.editor.Volunteer2\xa1\x07\n\x06\x45\x64itor\x12\x65\n\x0f\x43reateCommunity\x12\'.org.couchers.editor.CreateCommunityReq\x1a\'.org.couchers.api.communities.Community\"\x00\x12\x65\n\x0fUpdateCommunity\x12\'.org.couchers.editor.UpdateCommunityReq\x1a\'.org.couchers.api.communities.Community\"\x00\x12\x98\x01\n ListEventCommunityInviteRequests\x12\x38.org.couchers.editor.ListEventCommunityInviteRequestsReq\x1a\x38.org.couchers.editor.ListEventCommunityInviteRequestsRes\"\x00\x12\x9b\x01\n!DecideEventCommunityInviteRequest\x12\x39.org.couchers.editor.DecideEventCommunityInviteRequestReq\x1a\x39.org.couchers.editor.DecideEventCommunityInviteRequestRes\"\x00\x12\x66\n\x18SendBlogPostNotification\x12\x30.org.couchers.editor.SendBlogPostNotificationReq\x1a\x16.google.protobuf.Empty\"\x00\x12`\n\x11MakeUserVolunteer\x12).org.couchers.editor.MakeUserVolunteerReq\x1a\x1e.org.couchers.editor.Volunteer\"\x00\x12\\\n\x0fUpdateVolunteer\x12\'.org.couchers.editor.UpdateVolunteerReq\x1a\x1e.org.couchers.editor.Volunteer\"\x00\x12\x62\n\x0eListVolunteers\x12&.org.couchers.editor.ListVolunteersReq\x1a&.org.couchers.editor.ListVolunteersRes\"\x00\x1a\x04\x88\xb5\x18\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'editor_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_EDITOR']._loaded_options = None
  _globals['_EDITOR']._serialized_options = b'\210\265\030\005'
  _globals['_CREATECOMMUNITYREQ']._serialized_start=136
  _globals['_CREATECOMMUNITYREQ']._serialized_end=251
  _globals['_UPDATECOMMUNITYREQ']._serialized_start=253
  _globals['_UPDATECOMMUNITYREQ']._serialized_end=371
  _globals['_LISTEVENTCOMMUNITYINVITEREQUESTSREQ']._serialized_start=373
  _globals['_LISTEVENTCOMMUNITYINVITEREQUESTSREQ']._serialized_end=449
  _globals['_EVENTCOMMUNITYINVITEREQUEST']._serialized_start=452
  _globals['_EVENTCOMMUNITYINVITEREQUEST']._serialized_end=614
  _globals['_LISTEVENTCOMMUNITYINVITEREQUESTSRES']._serialized_start=617
  _globals['_LISTEVENTCOMMUNITYINVITEREQUESTSRES']._serialized_end=747
  _globals['_DECIDEEVENTCOMMUNITYINVITEREQUESTREQ']._serialized_start=749
  _globals['_DECIDEEVENTCOMMUNITYINVITEREQUESTREQ']._serialized_end=847
  _globals['_DECIDEEVENTCOMMUNITYINVITEREQUESTRES']._serialized_start=849
  _globals['_DECIDEEVENTCOMMUNITYINVITEREQUESTRES']._serialized_end=887
  _globals['_SENDBLOGPOSTNOTIFICATIONREQ']._serialized_start=889
  _globals['_SENDBLOGPOSTNOTIFICATIONREQ']._serialized_end=961
  _globals['_MAKEUSERVOLUNTEERREQ']._serialized_start=963
  _globals['_MAKEUSERVOLUNTEERREQ']._serialized_end=1073
  _globals['_UPDATEVOLUNTEERREQ']._serialized_start=1076
  _globals['_UPDATEVOLUNTEERREQ']._serialized_end=1380
  _globals['_LISTVOLUNTEERSREQ']._serialized_start=1382
  _globals['_LISTVOLUNTEERSREQ']._serialized_end=1423
  _globals['_VOLUNTEER']._serialized_start=1426
  _globals['_VOLUNTEER']._serialized_end=1821
  _globals['_LISTVOLUNTEERSRES']._serialized_start=1823
  _globals['_LISTVOLUNTEERSRES']._serialized_end=1894
  _globals['_EDITOR']._serialized_start=1897
  _globals['_EDITOR']._serialized_end=2826
# @@protoc_insertion_point(module_scope)



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import events_pb2
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import sys
import typing

if sys.version_info >= (3, 13):
    import typing as typing_extensions
else:
    import typing_extensions

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

GRPC_GENERATED_VERSION: str
GRPC_VERSION: str
class EventsServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def CreateEvent(
        self,
        request: events_pb2.CreateEventReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[events_pb2.Event, collections.abc.Awaitable[events_pb2.Event]]:
        """Creates an event, only one instance, add more with ScheduleEvent"""

    @abc.abstractmethod
    def ScheduleEvent(
        self,
        request: events_pb2.ScheduleEventReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[events_pb2.Event, collections.abc.Awaitable[events_pb2.Event]]:
        """Schedules a new occurrence of an existing event"""

    @abc.abstractmethod
    def UpdateEvent(
        self,
        request: events_pb2.UpdateEventReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[events_pb2.Event, collections.abc.Awaitable[events_pb2.Event]]:
        """Edit an event"""

    @abc.abstractmethod
    def GetEvent(
        self,
        request: events_pb2.GetEventReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[events_pb2.Event, collections.abc.Awaitable[events_pb2.Event]]:
        """Gets an event"""

    @abc.abstractmethod
    def CancelEvent(
        self,
        request: events_pb2.CancelEventReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Cancels an event"""

    @abc.abstractmethod
    def RequestCommunityInvite(
        self,
        request: events_pb2.RequestCommunityInviteReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Requests that a notification/email invitation about the event is sent out to the community"""

    @abc.abstractmethod
    def ListEventOccurrences(
        self,
        request: events_pb2.ListEventOccurrencesReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[events_pb2.ListEventOccurrencesRes, collections.abc.Awaitable[events_pb2.ListEventOccurrencesRes]]:
        """List all occurrences of a recurring event"""

    @abc.abstractmethod
    def ListEventAttendees(
        self,
        request: events_pb2.ListEventAttendeesReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[events_pb2.ListEventAttendeesRes, collections.abc.Awaitable[events_pb2.ListEventAttendeesRes]]:
        """Paginated list of event attendees"""

    @abc.abstractmethod
    def ListEventSubscribers(
        self,
        request: events_pb2.ListEventSubscribersReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[events_pb2.ListEventSubscribersRes, collections.abc.Awaitable[events_pb2.ListEventSubscribersRes]]:
        """Paginated list of event subscribers"""

    @abc.abstractmethod
    def ListEventOrganizers(
        self,
        request: events_pb2.ListEventOrganizersReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[events_pb2.ListEventOrganizersRes, collections.abc.Awaitable[events_pb2.ListEventOrganizersRes]]:
        """Paginated list of event organizers"""

    @abc.abstractmethod
    def TransferEvent(
        self,
        request: events_pb2.TransferEventReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[events_pb2.Event, collections.abc.Awaitable[events_pb2.Event]]:
        """Transfer an event you own to either a group or a community"""

    @abc.abstractmethod
    def SetEventSubscription(
        self,
        request: events_pb2.SetEventSubscriptionReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[events_pb2.Event, collections.abc.Awaitable[events_pb2.Event]]:
        """Subscribe to get notifications about all occurrences of an event"""

    @abc.abstractmethod
    def SetEventAttendance(
        self,
        request: events_pb2.SetEventAttendanceReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[events_pb2.Event, collections.abc.Awaitable[events_pb2.Event]]:
        """RSVP/change going status for an occurrence of an event"""

    @abc.abstractmethod
    def InviteEventOrganizer(
        self,
        request: events_pb2.InviteEventOrganizerReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Invite another user to become an organizer of this event"""

    @abc.abstractmethod
    def RemoveEventOrganizer(
        self,
        request: events_pb2.RemoveEventOrganizerReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[google.protobuf.empty_pb2.Empty, collections.abc.Awaitable[google.protobuf.empty_pb2.Empty]]:
        """Remove yourself as an event organizer"""

    @abc.abstractmethod
    def ListMyEvents(
        self,
        request: events_pb2.ListMyEventsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[events_pb2.ListMyEventsRes, collections.abc.Awaitable[events_pb2.ListMyEventsRes]]:
        """Lists all subscribed, attending"""

    @abc.abstractmethod
    def ListAllEvents(
        self,
        request: events_pb2.ListAllEventsReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[events_pb2.ListAllEventsRes, collections.abc.Awaitable[events_pb2.ListAllEventsRes]]:
        """Lists all events"""

def add_EventsServicer_to_server(servicer: EventsServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class BlockUserReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERNAME_FIELD_NUMBER: builtins.int
    username: builtins.str
    def __init__(
        self,
        *,
        username: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["username", b"username"]) -> None: ...

Global___BlockUserReq: typing_extensions.TypeAlias = BlockUserReq

@typing.final
class UnblockUserReq(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERNAME_FIELD_NUMBER: builtins.int
    username: builtins.str
    def __init__(
        self,
        *,
        username: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["username", b"username"]) -> None: ...

Global___UnblockUserReq: typing_extensions.TypeAlias = UnblockUserReq

@typing.final
class BlockedUser(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERNAME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AVATAR_THUMBNAIL_URL_FIELD_NUMBER: builtins.int
    username: builtins.str
    name: builtins.str
    avatar_thumbnail_url: builtins.str
    def __init__(
        self,
        *,
        username: builtins.str | None = ...,
        name: builtins.str | None = ...,
        avatar_thumbnail_url: builtins.str | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["avatar_thumbnail_url", b"avatar_thumbnail_url", "name", b"name", "username", b"username"]) -> None: ...

Global___BlockedUser: typing_extensions.TypeAlias = BlockedUser

@typing.final
class GetBlockedUsersRes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BLOCKED_USERS_FIELD_NUMBER: builtins.int
    @property
    def blocked_users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___BlockedUser]: ...
    def __init__(
        self,
        *,
        blocked_users: collections.abc.Iterable[Global___BlockedUser] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["blocked_users", b"blocked_users"]) -> None: ...

Global___GetBlockedUsersRes: typing_extensions.TypeAlias = GetBlockedUsersRes



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: galleries.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fgalleries.proto\x12\x1aorg.couchers.api.galleries\x1a\x11\x61nnotations.proto\"]\n\x10PhotoGalleryItem\x12\x0f\n\x07item_id\x18\x01 \x01(\x03\x12\x10\n\x08\x66ull_url\x18\x02 \x01(\t\x12\x15\n\rthumbnail_url\x18\x03 \x01(\t\x12\x0f\n\x07\x63\x61ption\x18\x04 \x01(\t\"r\n\x0cPhotoGallery\x12\x12\n\ngallery_id\x18\x01 \x01(\x03\x12<\n\x06photos\x18\x02 \x03(\x0b\x32,.org.couchers.api.galleries.PhotoGalleryItem\x12\x10\n\x08\x63\x61n_edit\x18\x03 \x01(\x08\"#\n\rGetGalleryReq\x12\x12\n\ngallery_id\x18\x01 \x01(\x03\"O\n\x14\x41\x64\x64PhotoToGalleryReq\x12\x12\n\ngallery_id\x18\x01 \x01(\x03\x12\x12\n\nupload_key\x18\x02 \x01(\t\x12\x0f\n\x07\x63\x61ption\x18\x03 \x01(\t\"@\n\x19RemovePhotoFromGalleryReq\x12\x12\n\ngallery_id\x18\x01 \x01(\x03\x12\x0f\n\x07item_id\x18\x02 \x01(\x03\"J\n\x0cMovePhotoReq\x12\x12\n\ngallery_id\x18\x01 \x01(\x03\x12\x0f\n\x07item_id\x18\x02 \x01(\x03\x12\x15\n\rafter_item_id\x18\x03 \x01(\x03\"M\n\x15UpdatePhotoCaptionReq\x12\x12\n\ngallery_id\x18\x01 \x01(\x03\x12\x0f\n\x07item_id\x18\x02 \x01(\x03\x12\x0f\n\x07\x63\x61ption\x18\x03 \x01(\t\"+\n\x15GetGalleryEditInfoReq\x12\x12\n\ngallery_id\x18\x01 \x01(\x03\"\\\n\x15GetGalleryEditInfoRes\x12\x12\n\ngallery_id\x18\x01 \x01(\x03\x12\x12\n\nmax_photos\x18\x02 \x01(\r\x12\x1b\n\x13\x63urrent_photo_count\x18\x03 \x01(\r2\xbc\x05\n\tGalleries\x12\x63\n\nGetGallery\x12).org.couchers.api.galleries.GetGalleryReq\x1a(.org.couchers.api.galleries.PhotoGallery\"\x00\x12q\n\x11\x41\x64\x64PhotoToGallery\x12\x30.org.couchers.api.galleries.AddPhotoToGalleryReq\x1a(.org.couchers.api.galleries.PhotoGallery\"\x00\x12{\n\x16RemovePhotoFromGallery\x12\x35.org.couchers.api.galleries.RemovePhotoFromGalleryReq\x1a(.org.couchers.api.galleries.PhotoGallery\"\x00\x12\x61\n\tMovePhoto\x12(.org.couchers.api.galleries.MovePhotoReq\x1a(.org.couchers.api.galleries.PhotoGallery\"\x00\x12s\n\x12UpdatePhotoCaption\x12\x31.org.couchers.api.galleries.UpdatePhotoCaptionReq\x1a(.org.couchers.api.galleries.PhotoGallery\"\x00\x12|\n\x12GetGalleryEditInfo\x12\x31.org.couchers.api.galleries.GetGalleryEditInfoReq\x1a\x31.org.couchers.api.galleries.GetGalleryEditInfoRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'galleries_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_GALLERIES']._loaded_options = None
  _globals['_GALLERIES']._serialized_options = b'\210\265\030\003'
  _globals['_PHOTOGALLERYITEM']._serialized_start=66
  _globals['_PHOTOGALLERYITEM']._serialized_end=159
  _globals['_PHOTOGALLERY']._serialized_start=161
  _globals['_PHOTOGALLERY']._serialized_end=275
  _globals['_GETGALLERYREQ']._serialized_start=277
  _globals['_GETGALLERYREQ']._serialized_end=312
  _globals['_ADDPHOTOTOGALLERYREQ']._serialized_start=314
  _globals['_ADDPHOTOTOGALLERYREQ']._serialized_end=393
  _globals['_REMOVEPHOTOFROMGALLERYREQ']._serialized_start=395
  _globals['_REMOVEPHOTOFROMGALLERYREQ']._serialized_end=459
  _globals['_MOVEPHOTOREQ']._serialized_start=461
  _globals['_MOVEPHOTOREQ']._serialized_end=535
  _globals['_UPDATEPHOTOCAPTIONREQ']._serialized_start=537
  _globals['_UPDATEPHOTOCAPTIONREQ']._serialized_end=614
  _globals['_GETGALLERYEDITINFOREQ']._serialized_start=616
  _globals['_GETGALLERYEDITINFOREQ']._serialized_end=659
  _globals['_GETGALLERYEDITINFORES']._serialized_start=661
  _globals['_GETGALLERYEDITINFORES']._serialized_end=753
  _globals['_GALLERIES']._serialized_start=756
  _globals['_GALLERIES']._serialized_end=1456
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blocking.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import annotations_pb2 as annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x62locking.proto\x12\x15org.couchers.blocking\x1a\x1bgoogle/protobuf/empty.proto\x1a\x11\x61nnotations.proto\" \n\x0c\x42lockUserReq\x12\x10\n\x08username\x18\x01 \x01(\t\"\"\n\x0eUnblockUserReq\x12\x10\n\x08username\x18\x01 \x01(\t\"K\n\x0b\x42lockedUser\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1c\n\x14\x61vatar_thumbnail_url\x18\x03 \x01(\t\"O\n\x12GetBlockedUsersRes\x12\x39\n\rblocked_users\x18\x01 \x03(\x0b\x32\".org.couchers.blocking.BlockedUser2\x80\x02\n\x08\x42locking\x12H\n\tBlockUser\x12#.org.couchers.blocking.BlockUserReq\x1a\x16.google.protobuf.Empty\x12L\n\x0bUnblockUser\x12%.org.couchers.blocking.UnblockUserReq\x1a\x16.google.protobuf.Empty\x12V\n\x0fGetBlockedUsers\x12\x16.google.protobuf.Empty\x1a).org.couchers.blocking.GetBlockedUsersRes\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'blocking_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_BLOCKING']._loaded_options = None
  _globals['_BLOCKING']._serialized_options = b'\210\265\030\003'
  _globals['_BLOCKUSERREQ']._serialized_start=89
  _globals['_BLOCKUSERREQ']._serialized_end=121
  _globals['_UNBLOCKUSERREQ']._serialized_start=123
  _globals['_UNBLOCKUSERREQ']._serialized_end=157
  _globals['_BLOCKEDUSER']._serialized_start=159
  _globals['_BLOCKEDUSER']._serialized_end=234
  _globals['_GETBLOCKEDUSERSRES']._serialized_start=236
  _globals['_GETBLOCKEDUSERSRES']._serialized_end=315
  _globals['_BLOCKING']._serialized_start=318
  _globals['_BLOCKING']._serialized_end=574
# @@protoc_insertion_point(module_scope)



from sqlalchemy import orm
from couchers.context import CouchersContext
"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import gallery_pb2
import grpc
import grpc.aio
import sys
import typing

if sys.version_info >= (3, 13):
    import typing as typing_extensions
else:
    import typing_extensions

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

GRPC_GENERATED_VERSION: str
GRPC_VERSION: str
class GalleryServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def GetGallery(
        self,
        request: gallery_pb2.GetGalleryReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[gallery_pb2.PhotoGallery, collections.abc.Awaitable[gallery_pb2.PhotoGallery]]:
        """Get a specific gallery by ID"""

    @abc.abstractmethod
    def AddPhotoToGallery(
        self,
        request: gallery_pb2.AddPhotoToGalleryReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[gallery_pb2.PhotoGallery, collections.abc.Awaitable[gallery_pb2.PhotoGallery]]:
        """Add a photo to your gallery (appended to end)"""

    @abc.abstractmethod
    def RemovePhotoFromGallery(
        self,
        request: gallery_pb2.RemovePhotoFromGalleryReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[gallery_pb2.PhotoGallery, collections.abc.Awaitable[gallery_pb2.PhotoGallery]]:
        """Remove a photo from your gallery"""

    @abc.abstractmethod
    def MovePhoto(
        self,
        request: gallery_pb2.MovePhotoReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[gallery_pb2.PhotoGallery, collections.abc.Awaitable[gallery_pb2.PhotoGallery]]:
        """Move a photo to a new position in the gallery"""

    @abc.abstractmethod
    def UpdatePhotoCaption(
        self,
        request: gallery_pb2.UpdatePhotoCaptionReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[gallery_pb2.PhotoGallery, collections.abc.Awaitable[gallery_pb2.PhotoGallery]]:
        """Update the caption of a specific photo"""

    @abc.abstractmethod
    def GetGalleryEditInfo(
        self,
        request: gallery_pb2.GetGalleryEditInfoReq,
        context: CouchersContext,
        session: orm.Session,
    ) -> typing.Union[gallery_pb2.GetGalleryEditInfoRes, collections.abc.Awaitable[gallery_pb2.GetGalleryEditInfoRes]]:
        """Get edit info for a gallery you own (e.g., max_photos)"""

def add_GalleryServicer_to_server(servicer: GalleryServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import account_pb2 as account__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class AccountStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetAccountInfo = channel.unary_unary(
                '/org.couchers.api.account.Account/GetAccountInfo',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=account__pb2.GetAccountInfoRes.FromString,
                )
        self.ChangePasswordV2 = channel.unary_unary(
                '/org.couchers.api.account.Account/ChangePasswordV2',
                request_serializer=account__pb2.ChangePasswordV2Req.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ChangeEmailV2 = channel.unary_unary(
                '/org.couchers.api.account.Account/ChangeEmailV2',
                request_serializer=account__pb2.ChangeEmailV2Req.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.GetContributorFormInfo = channel.unary_unary(
                '/org.couchers.api.account.Account/GetContributorFormInfo',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=account__pb2.GetContributorFormInfoRes.FromString,
                )
        self.FillContributorForm = channel.unary_unary(
                '/org.couchers.api.account.Account/FillContributorForm',
                request_serializer=account__pb2.FillContributorFormReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ChangeLanguagePreference = channel.unary_unary(
                '/org.couchers.api.account.Account/ChangeLanguagePreference',
                request_serializer=account__pb2.ChangeLanguagePreferenceReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ChangePhone = channel.unary_unary(
                '/org.couchers.api.account.Account/ChangePhone',
                request_serializer=account__pb2.ChangePhoneReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.VerifyPhone = channel.unary_unary(
                '/org.couchers.api.account.Account/VerifyPhone',
                request_serializer=account__pb2.VerifyPhoneReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.InitiateStrongVerification = channel.unary_unary(
                '/org.couchers.api.account.Account/InitiateStrongVerification',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=account__pb2.InitiateStrongVerificationRes.FromString,
                )
        self.GetStrongVerificationAttemptStatus = channel.unary_unary(
                '/org.couchers.api.account.Account/GetStrongVerificationAttemptStatus',
                request_serializer=account__pb2.GetStrongVerificationAttemptStatusReq.SerializeToString,
                response_deserializer=account__pb2.GetStrongVerificationAttemptStatusRes.FromString,
                )
        self.DeleteStrongVerificationData = channel.unary_unary(
                '/org.couchers.api.account.Account/DeleteStrongVerificationData',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.DeleteAccount = channel.unary_unary(
                '/org.couchers.api.account.Account/DeleteAccount',
                request_serializer=account__pb2.DeleteAccountReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListModNotes = channel.unary_unary(
                '/org.couchers.api.account.Account/ListModNotes',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=account__pb2.ListModNotesRes.FromString,
                )
        self.ListActiveSessions = channel.unary_unary(
                '/org.couchers.api.account.Account/ListActiveSessions',
                request_serializer=account__pb2.ListActiveSessionsReq.SerializeToString,
                response_deserializer=account__pb2.ListActiveSessionsRes.FromString,
                )
        self.LogOutSession = channel.unary_unary(
                '/org.couchers.api.account.Account/LogOutSession',
                request_serializer=account__pb2.LogOutSessionReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.LogOutOtherSessions = channel.unary_unary(
                '/org.couchers.api.account.Account/LogOutOtherSessions',
                request_serializer=account__pb2.LogOutOtherSessionsReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.SetProfilePublicVisibility = channel.unary_unary(
                '/org.couchers.api.account.Account/SetProfilePublicVisibility',
                request_serializer=account__pb2.SetProfilePublicVisibilityReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.CreateInviteCode = channel.unary_unary(
                '/org.couchers.api.account.Account/CreateInviteCode',
                request_serializer=account__pb2.CreateInviteCodeReq.SerializeToString,
                response_deserializer=account__pb2.CreateInviteCodeRes.FromString,
                )
        self.DisableInviteCode = channel.unary_unary(
                '/org.couchers.api.account.Account/DisableInviteCode',
                request_serializer=account__pb2.DisableInviteCodeReq.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ListInviteCodes = channel.unary_unary(
                '/org.couchers.api.account.Account/ListInviteCodes',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=account__pb2.ListInviteCodesRes.FromString,
                )
        self.GetReminders = channel.unary_unary(
                '/org.couchers.api.account.Account/GetReminders',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=account__pb2.GetRemindersRes.FromString,
                )
        self.GetMyVolunteerInfo = channel.unary_unary(
                '/org.couchers.api.account.Account/GetMyVolunteerInfo',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=account__pb2.GetMyVolunteerInfoRes.FromString,
                )
        self.UpdateMyVolunteerInfo = channel.unary_unary(
                '/org.couchers.api.account.Account/UpdateMyVolunteerInfo',
                request_serializer=account__pb2.UpdateMyVolunteerInfoReq.SerializeToString,
                response_deserializer=account__pb2.GetMyVolunteerInfoRes.FromString,
                )


class AccountServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetAccountInfo(self, request, context):
        """account management APIs
        Get information about the user's account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChangePasswordV2(self, request, context):
        """Change the user's password
        we will send and an email to the user saying their password was changed
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChangeEmailV2(self, request, context):
        """Change the user's email address
        We will send a notification email to the old email, and confirmation email to the new email
        Raises INVALID_ARGUMENT if password is too small, too large, insecure, wrong or not supplied.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetContributorFormInfo(self, request, context):
        """Returns info related to filling out the contributor form
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FillContributorForm(self, request, context):
        """Fill the contributor form; this can be done multiple times
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChangeLanguagePreference(self, request, context):
        """Changes the user's interface language
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChangePhone(self, request, context):
        """Set/Change/Remove phone number. An verification sms with a 6-digit code will be sent out,
        And returned in a call to in VerifyPhone() to complete the phone number change.
        An INVALID_ARGUMENT is returned if the phone number is not formatted according to E.164.
        A RESOURCE_EXHAUSTED error code indicates that you have done too many changes lately.
        An UNIMPLEMENTED error code indicates that sms to your operator is not supported.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VerifyPhone(self, request, context):
        """Enter the code you got in the sms. Other accounts using the same phone number will
        lose their verification status.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InitiateStrongVerification(self, request, context):
        """Initiates a strong verification (passport read)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetStrongVerificationAttemptStatus(self, request, context):
        """Gets the status of a strong verification attempt
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteStrongVerificationData(self, request, context):
        """Deletes full SV data (but not minimal data), see the ToS
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteAccount(self, request, context):
        """Sends email with confirmation link containing token to delete account
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListModNotes(self, request, context):
        """Lists all the user's mod notes: only ack'd ones because otherwise the user is jailed
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListActiveSessions(self, request, context):
        """Lists all the user's current sessions
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LogOutSession(self, request, context):
        """Logs the user out of the given session, cannot be current one
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LogOutOtherSessions(self, request, context):
        """Logs the user out of all other sessions except this one
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetProfilePublicVisibility(self, request, context):
        """Set what info is shown to logged-out users
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateInviteCode(self, request, context):
        """Creates a new unique invite code for the current user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DisableInviteCode(self, request, context):
        """Disables the given invite code created by the user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListInviteCodes(self, request, context):
        """Lists all invite codes created by the user, with usage count
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetReminders(self, request, context):
        """Reminders to be shown on dashboard for things the user should do
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMyVolunteerInfo(self, request, context):
        """Returns info about the current user's volunteer status if they are volunteer
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateMyVolunteerInfo(self, request, context):
        """Updates the current user's volunteer status if they are volunteer
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AccountServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetAccountInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccountInfo,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=account__pb2.GetAccountInfoRes.SerializeToString,
            ),
            'ChangePasswordV2': grpc.unary_unary_rpc_method_handler(
                    servicer.ChangePasswordV2,
                    request_deserializer=account__pb2.ChangePasswordV2Req.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ChangeEmailV2': grpc.unary_unary_rpc_method_handler(
                    servicer.ChangeEmailV2,
                    request_deserializer=account__pb2.ChangeEmailV2Req.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'GetContributorFormInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetContributorFormInfo,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=account__pb2.GetContributorFormInfoRes.SerializeToString,
            ),
            'FillContributorForm': grpc.unary_unary_rpc_method_handler(
                    servicer.FillContributorForm,
                    request_deserializer=account__pb2.FillContributorFormReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ChangeLanguagePreference': grpc.unary_unary_rpc_method_handler(
                    servicer.ChangeLanguagePreference,
                    request_deserializer=account__pb2.ChangeLanguagePreferenceReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ChangePhone': grpc.unary_unary_rpc_method_handler(
                    servicer.ChangePhone,
                    request_deserializer=account__pb2.ChangePhoneReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'VerifyPhone': grpc.unary_unary_rpc_method_handler(
                    servicer.VerifyPhone,
                    request_deserializer=account__pb2.VerifyPhoneReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'InitiateStrongVerification': grpc.unary_unary_rpc_method_handler(
                    servicer.InitiateStrongVerification,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=account__pb2.InitiateStrongVerificationRes.SerializeToString,
            ),
            'GetStrongVerificationAttemptStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.GetStrongVerificationAttemptStatus,
                    request_deserializer=account__pb2.GetStrongVerificationAttemptStatusReq.FromString,
                    response_serializer=account__pb2.GetStrongVerificationAttemptStatusRes.SerializeToString,
            ),
            'DeleteStrongVerificationData': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteStrongVerificationData,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'DeleteAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteAccount,
                    request_deserializer=account__pb2.DeleteAccountReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListModNotes': grpc.unary_unary_rpc_method_handler(
                    servicer.ListModNotes,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=account__pb2.ListModNotesRes.SerializeToString,
            ),
            'ListActiveSessions': grpc.unary_unary_rpc_method_handler(
                    servicer.ListActiveSessions,
                    request_deserializer=account__pb2.ListActiveSessionsReq.FromString,
                    response_serializer=account__pb2.ListActiveSessionsRes.SerializeToString,
            ),
            'LogOutSession': grpc.unary_unary_rpc_method_handler(
                    servicer.LogOutSession,
                    request_deserializer=account__pb2.LogOutSessionReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'LogOutOtherSessions': grpc.unary_unary_rpc_method_handler(
                    servicer.LogOutOtherSessions,
                    request_deserializer=account__pb2.LogOutOtherSessionsReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'SetProfilePublicVisibility': grpc.unary_unary_rpc_method_handler(
                    servicer.SetProfilePublicVisibility,
                    request_deserializer=account__pb2.SetProfilePublicVisibilityReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'CreateInviteCode': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateInviteCode,
                    request_deserializer=account__pb2.CreateInviteCodeReq.FromString,
                    response_serializer=account__pb2.CreateInviteCodeRes.SerializeToString,
            ),
            'DisableInviteCode': grpc.unary_unary_rpc_method_handler(
                    servicer.DisableInviteCode,
                    request_deserializer=account__pb2.DisableInviteCodeReq.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ListInviteCodes': grpc.unary_unary_rpc_method_handler(
                    servicer.ListInviteCodes,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=account__pb2.ListInviteCodesRes.SerializeToString,
            ),
            'GetReminders': grpc.unary_unary_rpc_method_handler(
                    servicer.GetReminders,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=account__pb2.GetRemindersRes.SerializeToString,
            ),
            'GetMyVolunteerInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMyVolunteerInfo,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=account__pb2.GetMyVolunteerInfoRes.SerializeToString,
            ),
            'UpdateMyVolunteerInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateMyVolunteerInfo,
                    request_deserializer=account__pb2.UpdateMyVolunteerInfoReq.FromString,
                    response_serializer=account__pb2.GetMyVolunteerInfoRes.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'org.couchers.api.account.Account', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Account(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetAccountInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.account.Account/GetAccountInfo',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            account__pb2.GetAccountInfoRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChangePasswordV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.account.Account/ChangePasswordV2',
            account__pb2.ChangePasswordV2Req.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChangeEmailV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.account.Account/ChangeEmailV2',
            account__pb2.ChangeEmailV2Req.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetContributorFormInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.account.Account/GetContributorFormInfo',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            account__pb2.GetContributorFormInfoRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FillContributorForm(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.account.Account/FillContributorForm',
            account__pb2.FillContributorFormReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChangeLanguagePreference(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.account.Account/ChangeLanguagePreference',
            account__pb2.ChangeLanguagePreferenceReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChangePhone(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.account.Account/ChangePhone',
            account__pb2.ChangePhoneReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def VerifyPhone(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.account.Account/VerifyPhone',
            account__pb2.VerifyPhoneReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InitiateStrongVerification(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.account.Account/InitiateStrongVerification',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            account__pb2.InitiateStrongVerificationRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetStrongVerificationAttemptStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.account.Account/GetStrongVerificationAttemptStatus',
            account__pb2.GetStrongVerificationAttemptStatusReq.SerializeToString,
            account__pb2.GetStrongVerificationAttemptStatusRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteStrongVerificationData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.account.Account/DeleteStrongVerificationData',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.account.Account/DeleteAccount',
            account__pb2.DeleteAccountReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListModNotes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.account.Account/ListModNotes',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            account__pb2.ListModNotesRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListActiveSessions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.account.Account/ListActiveSessions',
            account__pb2.ListActiveSessionsReq.SerializeToString,
            account__pb2.ListActiveSessionsRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LogOutSession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.account.Account/LogOutSession',
            account__pb2.LogOutSessionReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LogOutOtherSessions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.account.Account/LogOutOtherSessions',
            account__pb2.LogOutOtherSessionsReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetProfilePublicVisibility(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.account.Account/SetProfilePublicVisibility',
            account__pb2.SetProfilePublicVisibilityReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateInviteCode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.account.Account/CreateInviteCode',
            account__pb2.CreateInviteCodeReq.SerializeToString,
            account__pb2.CreateInviteCodeRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DisableInviteCode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.account.Account/DisableInviteCode',
            account__pb2.DisableInviteCodeReq.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListInviteCodes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.account.Account/ListInviteCodes',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            account__pb2.ListInviteCodesRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetReminders(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.account.Account/GetReminders',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            account__pb2.GetRemindersRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMyVolunteerInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.account.Account/GetMyVolunteerInfo',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            account__pb2.GetMyVolunteerInfoRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateMyVolunteerInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/org.couchers.api.account.Account/UpdateMyVolunteerInfo',
            account__pb2.UpdateMyVolunteerInfoReq.SerializeToString,
            account__pb2.GetMyVolunteerInfoRes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: discussions.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import annotations_pb2 as annotations__pb2
from . import threads_pb2 as threads__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x64iscussions.proto\x12\x1corg.couchers.api.discussions\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x11\x61nnotations.proto\x1a\rthreads.proto\"\xb5\x02\n\nDiscussion\x12\x15\n\rdiscussion_id\x18\x01 \x01(\x03\x12\x0c\n\x04slug\x18\x02 \x01(\t\x12+\n\x07\x63reated\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\x0f\x63reator_user_id\x18\x04 \x01(\x03\x12\x1c\n\x12owner_community_id\x18\x05 \x01(\x03H\x00\x12\x18\n\x0eowner_group_id\x18\x06 \x01(\x03H\x00\x12\x13\n\x0bowner_title\x18\x0c \x01(\t\x12\r\n\x05title\x18\x07 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x08 \x01(\t\x12\x30\n\x06thread\x18\x0b \x01(\x0b\x32 .org.couchers.api.threads.Thread\x12\x14\n\x0c\x63\x61n_moderate\x18\n \x01(\x08\x42\x07\n\x05owner\"v\n\x13\x43reateDiscussionReq\x12\r\n\x05title\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x1c\n\x12owner_community_id\x18\x03 \x01(\x03H\x00\x12\x18\n\x0eowner_group_id\x18\x04 \x01(\x03H\x00\x42\x07\n\x05owner\")\n\x10GetDiscussionReq\x12\x15\n\rdiscussion_id\x18\x01 \x01(\x03\x32\xf3\x01\n\x0b\x44iscussions\x12q\n\x10\x43reateDiscussion\x12\x31.org.couchers.api.discussions.CreateDiscussionReq\x1a(.org.couchers.api.discussions.Discussion\"\x00\x12k\n\rGetDiscussion\x12..org.couchers.api.discussions.GetDiscussionReq\x1a(.org.couchers.api.discussions.Discussion\"\x00\x1a\x04\x88\xb5\x18\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'discussions_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DISCUSSIONS']._loaded_options = None
  _globals['_DISCUSSIONS']._serialized_options = b'\210\265\030\003'
  _globals['_DISCUSSION']._serialized_start=119
  _globals['_DISCUSSION']._serialized_end=428
  _globals['_CREATEDISCUSSIONREQ']._serialized_start=430
  _globals['_CREATEDISCUSSIONREQ']._serialized_end=548
  _globals['_GETDISCUSSIONREQ']._serialized_start=550
  _globals['_GETDISCUSSIONREQ']._serialized_end=591
  _globals['_DISCUSSIONS']._serialized_start=594
  _globals['_DISCUSSIONS']._serialized_end=837
# @@protoc_insertion_point(module_scope)
